/* automatically generated from launcher-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (launcher_dialog_ui)
#endif
#ifdef __GNUC__
static const char launcher_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char launcher_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.12\"/"
  "><object class=\"GtkListStore\" id=\"add-store\"><columns><column type="
  "\"GdkPixbuf\"/><column type=\"gchararray\"/><column type=\"GObject\"/><"
  "column type=\"gchararray\"/><column type=\"gchararray\"/></columns></ob"
  "ject><object class=\"GtkTreeModelFilter\" id=\"add-store-filter\"><prop"
  "erty name=\"child_model\">add-store</property></object><object class=\""
  "GtkListStore\" id=\"arrow-position-model\"><columns><column type=\"gcha"
  "rarray\"/></columns><data><row><col id=\"0\" translatable=\"yes\">Defau"
  "lt</col></row><row><col id=\"0\" translatable=\"yes\">North</col></row>"
  "<row><col id=\"0\" translatable=\"yes\">West</col></row><row><col id=\""
  "0\" translatable=\"yes\">East</col></row><row><col id=\"0\" translatabl"
  "e=\"yes\">South</col></row><row><col id=\"0\" translatable=\"yes\">Insi"
  "de Button</col></row></data></object><object class=\"GtkImage\" id=\"im"
  "age11\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"icon_name\">document-propertie"
  "s-symbolic</property><property name=\"icon_size\">1</property></object>"
  "<object class=\"GtkImage\" id=\"image12\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"icon_name\">list-remove-symbolic</property><property name=\"icon_si"
  "ze\">1</property></object><object class=\"GtkImage\" id=\"image13\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property><property name=\"icon_name\">document-new-symbolic</proper"
  "ty><property name=\"icon_size\">1</property></object><object class=\"Gt"
  "kImage\" id=\"image14\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"icon_name\">ap"
  "plications-internet-symbolic</property><property name=\"icon_size\">1</"
  "property></object><object class=\"GtkImage\" id=\"image15\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"icon_name\">list-add-symbolic</property><property"
  " name=\"icon_size\">1</property></object><object class=\"GtkImage\" id="
  "\"image16\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"icon_name\">go-up-symbolic"
  "</property><property name=\"icon_size\">1</property></object><object cl"
  "ass=\"GtkImage\" id=\"image18\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"icon_n"
  "ame\">go-down-symbolic</property><property name=\"icon_size\">1</proper"
  "ty></object><object class=\"GtkMenu\" id=\"popup-menu\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><child><object class=\"GtkImageMenuItem\" id=\"mi-move-up\"><property "
  "name=\"label\" translatable=\"yes\">Up</property><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"image\">image16</property><property name=\"use_stock\">False"
  "</property></object></child><child><object class=\"GtkImageMenuItem\" i"
  "d=\"mi-move-down\"><property name=\"label\" translatable=\"yes\">Down</"
  "property><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"image\">image18</property><pr"
  "operty name=\"use_stock\">False</property></object></child><child><obje"
  "ct class=\"GtkSeparatorMenuItem\" id=\"smi1\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property></object><"
  "/child><child><object class=\"GtkImageMenuItem\" id=\"mi-edit\"><proper"
  "ty name=\"label\" translatable=\"yes\">_Edit Item</property><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"use_underline\">True</property><property name=\"i"
  "mage\">image11</property><property name=\"use_stock\">False</property><"
  "/object></child><child><object class=\"GtkImageMenuItem\" id=\"mi-delet"
  "e\"><property name=\"label\" translatable=\"yes\">D_elete Item</propert"
  "y><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"use_underline\">True</property><prope"
  "rty name=\"image\">image12</property><property name=\"use_stock\">False"
  "</property></object></child><child><object class=\"GtkSeparatorMenuItem"
  "\" id=\"smi2\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property></object></child><child><object class=\""
  "GtkImageMenuItem\" id=\"mi-add\"><property name=\"label\" translatable="
  "\"yes\">Add Appli_cation</property><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">False</property><property name=\"use"
  "_underline\">True</property><property name=\"image\">image15</property>"
  "<property name=\"use_stock\">False</property></object></child><child><o"
  "bject class=\"GtkSeparatorMenuItem\" id=\"smi3\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property></obje"
  "ct></child><child><object class=\"GtkImageMenuItem\" id=\"mi-applicatio"
  "n\"><property name=\"label\" translatable=\"yes\">New _Application</pro"
  "perty><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"use_underline\">True</property><"
  "property name=\"image\">image13</property><property name=\"use_stock\">"
  "False</property></object></child><child><object class=\"GtkImageMenuIte"
  "m\" id=\"mi-link\"><property name=\"label\" translatable=\"yes\">New _L"
  "ink</property><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"use_underline\">True</pr"
  "operty><property name=\"image\">image14</property><property name=\"use_"
  "stock\">False</property></object></child></object><object class=\"GtkIm"
  "age\" id=\"image19\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"icon_name\">list-"
  "add</property></object><object class=\"GtkImage\" id=\"image6\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"icon_name\">help-browser</property></object><"
  "object class=\"GtkImage\" id=\"image7\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"icon_name\">window-close-symbolic</property></object><object class=\""
  "XfceTitledDialog\" id=\"dialog-add\"><property name=\"can_focus\">False"
  "</property><property name=\"title\" translatable=\"yes\">Add New Items<"
  "/property><property name=\"window_position\">center-on-parent</property"
  "><property name=\"default_width\">400</property><property name=\"defaul"
  "t_height\">400</property><property name=\"destroy_with_parent\">True</p"
  "roperty><property name=\"icon_name\">list-add</property><property name="
  "\"type_hint\">normal</property><property name=\"subtitle\" translatable"
  "=\"yes\">Add one or more existing items to the launcher</property><chil"
  "d internal-child=\"vbox\"><object class=\"GtkBox\" id=\"dialog-vbox4\">"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "False</property><property name=\"orientation\">vertical</property><prop"
  "erty name=\"spacing\">2</property><child internal-child=\"action_area\""
  "><object class=\"GtkButtonBox\" id=\"dialog-action_area4\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"layout_style\">end</property><child><object class="
  "\"GtkButton\" id=\"button-add\"><property name=\"label\" translatable=\""
  "yes\">_Add</property><property name=\"visible\">True</property><propert"
  "y name=\"sensitive\">False</property><property name=\"can_focus\">True<"
  "/property><property name=\"receives_default\">True</property><property "
  "name=\"image\">image19</property><property name=\"use_underline\">True<"
  "/property></object><packing><property name=\"expand\">False</property><"
  "property name=\"fill\">False</property><property name=\"position\">0</p"
  "roperty></packing></child><child><object class=\"GtkButton\" id=\"butto"
  "n-close\"><property name=\"label\" translatable=\"yes\">_Close</propert"
  "y><property name=\"visible\">True</property><property name=\"can_focus\""
  ">True</property><property name=\"receives_default\">True</property><pro"
  "perty name=\"image\">image7</property><property name=\"use_underline\">"
  "True</property></object><packing><property name=\"expand\">False</prope"
  "rty><property name=\"fill\">False</property><property name=\"position\""
  ">1</property></packing></child></object><packing><property name=\"expan"
  "d\">False</property><property name=\"fill\">False</property><property n"
  "ame=\"pack_type\">end</property><property name=\"position\">0</property"
  "></packing></child><child><object class=\"GtkBox\" id=\"vbox2\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"border_width\">6</property><property name=\"o"
  "rientation\">vertical</property><property name=\"spacing\">6</property>"
  "<child><object class=\"GtkBox\" id=\"hbox4\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"spacing\">6</property><child><object class=\"GtkLabel\" id=\"lab"
  "el4\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"label\" translatable=\"yes\">_Se"
  "arch:</property><property name=\"use_underline\">True</property><proper"
  "ty name=\"xalign\">1</property></object><packing><property name=\"expan"
  "d\">False</property><property name=\"fill\">True</property><property na"
  "me=\"position\">0</property></packing></child><child><object class=\"Gt"
  "kEntry\" id=\"add-search\"><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">True</property></object><packing><property n"
  "ame=\"expand\">False</property><property name=\"fill\">True</property><"
  "property name=\"position\">1</property></packing></child></object><pack"
  "ing><property name=\"expand\">False</property><property name=\"fill\">T"
  "rue</property><property name=\"position\">0</property></packing></child"
  "><child><object class=\"GtkScrolledWindow\" id=\"scrolledwindow1\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">True"
  "</property><property name=\"vexpand\">True</property><property name=\"s"
  "hadow_type\">etched-in</property><child><object class=\"GtkTreeView\" i"
  "d=\"add-treeview\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">True</property><property name=\"model\">add-store-fi"
  "lter</property><property name=\"headers_visible\">False</property><prop"
  "erty name=\"rules_hint\">True</property><property name=\"enable_search\""
  ">False</property><property name=\"tooltip_column\">3</property><child i"
  "nternal-child=\"selection\"><object class=\"GtkTreeSelection\"/></child"
  "><child><object class=\"GtkTreeViewColumn\" id=\"treeviewcolumn1\"><pro"
  "perty name=\"spacing\">2</property><child><object class=\"GtkCellRender"
  "erPixbuf\" id=\"addrenderericon\"/><attributes><attribute name=\"pixbuf"
  "\">0</attribute></attributes></child><child><object class=\"GtkCellRend"
  "ererText\" id=\"addrenderername\"/><attributes><attribute name=\"markup"
  "\">1</attribute></attributes></child></object></child></object></child>"
  "</object><packing><property name=\"expand\">True</property><property na"
  "me=\"fill\">True</property><property name=\"position\">1</property></pa"
  "cking></child></object><packing><property name=\"expand\">True</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">1<"
  "/property></packing></child></object></child><action-widgets><action-wi"
  "dget response=\"1\">button-add</action-widget><action-widget response=\""
  "0\">button-close</action-widget></action-widgets></object><object class"
  "=\"GtkImage\" id=\"image8\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"icon_name\""
  ">window-close-symbolic</property></object><object class=\"GtkListStore\""
  " id=\"item-store\"><columns><column type=\"GdkPixbuf\"/><column type=\""
  "gchararray\"/><column type=\"GObject\"/><column type=\"gchararray\"/></"
  "columns></object><object class=\"XfceTitledDialog\" id=\"dialog\"><prop"
  "erty name=\"can_focus\">False</property><property name=\"title\" transl"
  "atable=\"yes\">Launcher</property><property name=\"window_position\">ce"
  "nter</property><property name=\"default_width\">350</property><property"
  " name=\"default_height\">400</property><property name=\"icon_name\">org"
  ".xfce.panel.launcher</property><property name=\"type_hint\">normal</pro"
  "perty><child internal-child=\"vbox\"><object class=\"GtkBox\" id=\"dial"
  "og-vbox2\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"orientation\">vertical</pro"
  "perty><property name=\"spacing\">2</property><child internal-child=\"ac"
  "tion_area\"><object class=\"GtkButtonBox\" id=\"dialog-action_area2\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">F"
  "alse</property><property name=\"layout_style\">end</property><child><ob"
  "ject class=\"GtkButton\" id=\"help-button\"><property name=\"label\" tr"
  "anslatable=\"yes\">_Help</property><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">True</property><property name=\"rece"
  "ives_default\">True</property><property name=\"image\">image6</property"
  "><property name=\"use_underline\">True</property></object><packing><pro"
  "perty name=\"expand\">False</property><property name=\"fill\">False</pr"
  "operty><property name=\"position\">0</property><property name=\"seconda"
  "ry\">True</property></packing></child><child><object class=\"GtkButton\""
  " id=\"button2\"><property name=\"label\" translatable=\"yes\">_Close</p"
  "roperty><property name=\"visible\">True</property><property name=\"can_"
  "focus\">True</property><property name=\"receives_default\">True</proper"
  "ty><property name=\"image\">image8</property><property name=\"use_under"
  "line\">True</property></object><packing><property name=\"expand\">False"
  "</property><property name=\"fill\">False</property><property name=\"pos"
  "ition\">1</property></packing></child></object><packing><property name="
  "\"expand\">False</property><property name=\"fill\">False</property><pro"
  "perty name=\"pack_type\">end</property><property name=\"position\">0</p"
  "roperty></packing></child><child><object class=\"GtkNotebook\" id=\"not"
  "ebook2\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">True</property><property name=\"vexpand\">True</property><prop"
  "erty name=\"border_width\">6</property><child><object class=\"GtkBox\" "
  "id=\"hbox1\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"border_width\">6</property"
  "><property name=\"spacing\">6</property><child><object class=\"GtkScrol"
  "ledWindow\" id=\"scrolledwindow2\"><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">True</property><property name=\"hexp"
  "and\">True</property><property name=\"shadow_type\">etched-in</property"
  "><child><object class=\"GtkTreeView\" id=\"item-treeview\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">True</proper"
  "ty><property name=\"model\">item-store</property><property name=\"heade"
  "rs_visible\">False</property><property name=\"rules_hint\">True</proper"
  "ty><property name=\"enable_search\">False</property><property name=\"to"
  "oltip_column\">3</property><child internal-child=\"selection\"><object "
  "class=\"GtkTreeSelection\"/></child><child><object class=\"GtkTreeViewC"
  "olumn\" id=\"treeviewcolumn2\"><property name=\"spacing\">2</property><"
  "child><object class=\"GtkCellRendererPixbuf\" id=\"itemrenderericon\"/>"
  "<attributes><attribute name=\"pixbuf\">0</attribute></attributes></chil"
  "d><child><object class=\"GtkCellRendererText\" id=\"itemrenderername\"/"
  "><attributes><attribute name=\"markup\">1</attribute></attributes></chi"
  "ld></object></child></object></child></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">0</property></packing></child><child><object class"
  "=\"GtkBox\" id=\"vbox3\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"orientation\""
  ">vertical</property><property name=\"spacing\">6</property><child><obje"
  "ct class=\"GtkBox\"><property name=\"visible\">True</property><property"
  " name=\"can_focus\">False</property><property name=\"orientation\">vert"
  "ical</property><child><object class=\"GtkButton\" id=\"item-move-up\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">T"
  "rue</property><property name=\"receives_default\">True</property><prope"
  "rty name=\"tooltip_text\" translatable=\"yes\">Move currently selected "
  "item up by one row</property><child><object class=\"GtkImage\" id=\"ima"
  "ge2\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"icon_name\">go-up-symbolic</prop"
  "erty></object></child></object><packing><property name=\"expand\">False"
  "</property><property name=\"fill\">True</property><property name=\"posi"
  "tion\">0</property></packing></child><child><object class=\"GtkButton\""
  " id=\"item-move-down\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">True</property><property name=\"receives_default"
  "\">True</property><property name=\"tooltip_text\" translatable=\"yes\">"
  "Move currently selected item down by one row</property><child><object c"
  "lass=\"GtkImage\" id=\"image3\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"icon_n"
  "ame\">go-down-symbolic</property></object></child></object><packing><pr"
  "operty name=\"expand\">False</property><property name=\"fill\">True</pr"
  "operty><property name=\"position\">1</property></packing></child><style"
  "><class name=\"linked\"/></style></object><packing><property name=\"exp"
  "and\">False</property><property name=\"fill\">True</property><property "
  "name=\"position\">0</property></packing></child><child><object class=\""
  "GtkButton\" id=\"item-edit\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">True</property><property name=\"receives_d"
  "efault\">True</property><property name=\"tooltip_text\" translatable=\""
  "yes\">Edit the currently selected item</property><child><object class=\""
  "GtkImage\" id=\"image1\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"icon_name\">d"
  "ocument-properties-symbolic</property></object></child></object><packin"
  "g><property name=\"expand\">False</property><property name=\"fill\">Tru"
  "e</property><property name=\"position\">1</property></packing></child><"
  "child><object class=\"GtkButton\" id=\"item-delete\"><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">True</property><pr"
  "operty name=\"receives_default\">True</property><property name=\"toolti"
  "p_text\" translatable=\"yes\">Delete the currently selected item</prope"
  "rty><child><object class=\"GtkImage\" id=\"image9\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"icon_name\">list-remove-symbolic</property></object></chi"
  "ld></object><packing><property name=\"expand\">False</property><propert"
  "y name=\"fill\">True</property><property name=\"position\">3</property>"
  "</packing></child><child><object class=\"GtkButton\" id=\"item-add\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Tr"
  "ue</property><property name=\"receives_default\">True</property><proper"
  "ty name=\"tooltip_text\" translatable=\"yes\">Add one or more existing "
  "items to the launcher</property><child><object class=\"GtkImage\" id=\""
  "image4\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"icon_name\">list-add-symbolic"
  "</property></object></child></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">True</property><property name="
  "\"position\">4</property></packing></child><child><object class=\"GtkBu"
  "tton\" id=\"item-new\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">True</property><property name=\"receives_default"
  "\">True</property><property name=\"tooltip_text\" translatable=\"yes\">"
  "Add a new empty item</property><child><object class=\"GtkImage\" id=\"i"
  "mage10\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"icon_name\">document-new-symb"
  "olic</property></object></child></object><packing><property name=\"expa"
  "nd\">False</property><property name=\"fill\">True</property><property n"
  "ame=\"position\">4</property></packing></child><child><object class=\"G"
  "tkButton\" id=\"item-link\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">True</property><property name=\"receives_de"
  "fault\">True</property><property name=\"tooltip_text\" translatable=\"y"
  "es\">Add a new hyperlink</property><child><object class=\"GtkImage\" id"
  "=\"image5\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"icon_name\">applications-i"
  "nternet-symbolic</property></object></child></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">True</property"
  "><property name=\"position\">5</property></packing></child></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">1</property></packing></chi"
  "ld></object></child><child type=\"tab\"><object class=\"GtkLabel\" id=\""
  "label1\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"label\" translatable=\"yes\">"
  "General</property></object><packing><property name=\"tab_fill\">False</"
  "property></packing></child><child><object class=\"GtkBox\" id=\"vbox1\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"border_width\">6</property><property "
  "name=\"orientation\">vertical</property><property name=\"spacing\">6</p"
  "roperty><child><object class=\"GtkCheckButton\" id=\"disable-tooltips\""
  "><property name=\"label\" translatable=\"yes\">Disable t_ooltips</prope"
  "rty><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">True</property><property name=\"receives_default\">False</property>"
  "<property name=\"tooltip_text\" translatable=\"yes\">Select this option"
  " to disable the tooltips when moving over the panel button or menu item"
  "s.</property><property name=\"use_underline\">True</property><property "
  "name=\"draw_indicator\">True</property></object><packing><property name"
  "=\"expand\">False</property><property name=\"fill\">True</property><pro"
  "perty name=\"position\">0</property></packing></child><child><object cl"
  "ass=\"GtkCheckButton\" id=\"show-label\"><property name=\"label\" trans"
  "latable=\"yes\">Show _label instead of icon</property><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"receives_default\">False</property><property name=\"use_"
  "underline\">True</property><property name=\"draw_indicator\">True</prop"
  "erty></object><packing><property name=\"expand\">False</property><prope"
  "rty name=\"fill\">True</property><property name=\"position\">1</propert"
  "y></packing></child><child><object class=\"GtkCheckButton\" id=\"move-f"
  "irst\"><property name=\"label\" translatable=\"yes\">Show last _used it"
  "em in panel</property><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">True</property><property name=\"receives_default\""
  ">False</property><property name=\"tooltip_text\" translatable=\"yes\">S"
  "elect this option to move the clicked menu item to the panel.</property"
  "><property name=\"use_underline\">True</property><property name=\"draw_"
  "indicator\">True</property></object><packing><property name=\"expand\">"
  "False</property><property name=\"fill\">True</property><property name=\""
  "position\">2</property></packing></child><child><object class=\"GtkBox\""
  " id=\"hbox2\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"spacing\">12</property><"
  "child><object class=\"GtkLabel\" id=\"arrow-position-label\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"label\" translatable=\"yes\">_Arrow button posit"
  "ion:</property><property name=\"use_underline\">True</property></object"
  "><packing><property name=\"expand\">False</property><property name=\"fi"
  "ll\">True</property><property name=\"position\">0</property></packing><"
  "/child><child><object class=\"GtkComboBox\" id=\"arrow-position\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">False"
  "</property><property name=\"model\">arrow-position-model</property><chi"
  "ld><object class=\"GtkCellRendererText\" id=\"cellrenderertext1\"/><att"
  "ributes><attribute name=\"text\">0</attribute></attributes></child></ob"
  "ject><packing><property name=\"expand\">True</property><property name=\""
  "fill\">True</property><property name=\"position\">1</property></packing"
  "></child></object><packing><property name=\"expand\">False</property><p"
  "roperty name=\"fill\">True</property><property name=\"position\">3</pro"
  "perty></packing></child></object><packing><property name=\"position\">1"
  "</property></packing></child><child type=\"tab\"><object class=\"GtkLab"
  "el\" id=\"label5\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">False</property><property name=\"label\" translatabl"
  "e=\"yes\">Advanced</property></object><packing><property name=\"positio"
  "n\">1</property><property name=\"tab_fill\">False</property></packing><"
  "/child></object><packing><property name=\"expand\">False</property><pro"
  "perty name=\"fill\">True</property><property name=\"position\">1</prope"
  "rty></packing></child></object></child><action-widgets><action-widget r"
  "esponse=\"1\">help-button</action-widget><action-widget response=\"0\">"
  "button2</action-widget></action-widgets></object></interface>"
};

static const unsigned launcher_dialog_ui_length = 24414u;

